@@ -31,7 +31,7 @@
 #'   maxiter: maximum iterations used \item refit: if TRUE, detection function
 #'   will be fitted more than once if parameters are at a boundary or when
 #'   convergence is not achieved \item nrefits: number of refittings \item
-#'   \item mono: if TRUE montonicity will be enforced \item
+#'   \item mono: if TRUE monotonicity will be enforced \item
 #'   mono.strict: if TRUE, then strict monotonicity is enforced; otherwise weak
 #'   \item width: radius of point count or half-width of strip \item
 #'   standardize: if TRUE, detection function is scaled so g(0)=1 \item ddfobj:
@@ -40,6 +40,7 @@
 #'   list of formulas for detection function model (probably can remove this)
 #'   }}
 #' @author Dave Miller; Jeff Laake
+#' @importFrom numDeriv hessian
 detfct.fit <- function(ddfobj, optim.options, bounds, misc.options){
   # Functions Used: assign.par, detfct.fit.opt, get.par
 
@@ -88,6 +89,12 @@ detfct.fit <- function(ddfobj, optim.options, bounds, misc.options){
 
     lt <- detfct.fit.opt(ddfobj, optim.options, bounds, misc.options)
 
+    # get the Hessian for the monotonicity model
+    if(misc.options$mono){
+      hess <- numDeriv::hessian(flnl, lt$par,
+                                ddfobj=ddfobj, misc.options=misc.options)
+      attr(lt, "details") <- list(nhatend=hess)
+    }
   }else{
   # Otherwise we need to play around...
 
